import { HttpService } from './http.service';
import { ChatInfoModel } from '../models/chat-info.model';
import { ResponseListModel } from '../models/response-list.model';
export declare class ChatsService {
    private httpService;
    /**
     * Base URL (точка входа) в микросервис сообщений
     */
    private messagesEndPoint;
    constructor(httpService: HttpService);
    /**
     * Получение всех чатов для текущего пользователя
     * @param {string} lastChatGuid Идентфиикатор последнего чата
     * @param {string} stopChatGuid Идентификатор чата, до которого получить информацию
     * @param {any} query Дополнительные параметры
     * @returns {Promise<ResponseListModel<ChatInfoModel>>}
     */
    getAllChats(lastChatGuid?: string, stopChatGuid?: string, query?: any): Promise<ResponseListModel<ChatInfoModel>>;
    /**
     * Получение всех чатов для пересылки сообщений
     * @param {string} lastChatGuid Идентификатор последнего чата
     * @param {string} stopChatGuid Идентификатор чата, до которого получить информацию
     * @param {any} query Дополнительные параметры
     * @returns {Promise<ResponseListModel<ChatInfoModel>>}
     */
    getForwardedChats(lastChatGuid?: string, stopChatGuid?: string, query?: any): Promise<ResponseListModel<ChatInfoModel>>;
    /**
     * Поиск по всем чатам текущего пользователя
     * @param {string} queryText Поисковой запрос
     * @param {any} query Дополнительные параметры запроса
     * @returns {Promise<ChatInfoModel[]>}
     */
    searchAllChats(queryText: string, query?: any): Promise<ResponseListModel<ChatInfoModel>>;
    /**
     * Поиск по всем чатам текущего пользователя
     * @param {string} queryText Поисковой запрос
     * @param {any} query Дополнительные параметры запроса
     * @returns {Promise<ChatInfoModel[]>}
     */
    searchForwardedChats(queryText: string, query?: any): Promise<ResponseListModel<ChatInfoModel>>;
    /**
     * Установка точки входа в микросервис сообщений
     * @param {string} endPoint
     */
    setMessagesEndPoint(endPoint: string): void;
}
