import { Inject, Injectable } from "@angular/core";
import { HttpService } from "./http.service";
import { DynamicRefsService } from "./dynamic-refs.service";
/**
 * Сервис строителя динамических справочников.
 */
var DynamicRefsBuilderService = (function () {
    function DynamicRefsBuilderService(httpService, cache) {
        this.httpService = httpService;
        this.cache = cache;
        /**
         * Хранит список инстансов сервисов динамических справочников
         *
         * @type {{}}
         */
        this.services = {};
    }
    /**
     * Устновка end point для справочников
     *
     * @param _refsEndPoint
     */
    DynamicRefsBuilderService.prototype.setRefsEndPoint = function (_refsEndPoint) {
        this.refsEndPoint = _refsEndPoint;
    };
    /**
     * Получить экземпляр динамического сервиса справочников.
     *
     * @param name имя справочника, например geo, spec
     * @returns {DynamicRefsService} экземпляр сервиса DynamicRefsService с инициализированными refName и endPoint
     */
    DynamicRefsBuilderService.prototype.getInstance = function (name) {
        if (!this.services.hasOwnProperty(name)) {
            var refService = new DynamicRefsService(this.httpService, this.cache);
            refService.refName = name;
            refService.setRefsEndPoint(this.refsEndPoint);
            this.services[name] = refService;
        }
        return this.services[name];
    };
    return DynamicRefsBuilderService;
}());
export { DynamicRefsBuilderService };
DynamicRefsBuilderService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DynamicRefsBuilderService.ctorParameters = function () { return [
    { type: HttpService, },
    { type: undefined, decorators: [{ type: Inject, args: ['StorageInterface',] },] },
]; };
//# sourceMappingURL=dynamic-refs-builder.service.js.map