export declare class ExternalResourceService {
    private static readonly defaultStyleAttributes;
    private static readonly defaultScriptAttributes;
    /**
     * Список уже загруженных на страницу скриптов
     *
     * @type {Array}
     */
    private loadedScripts;
    /**
     * Список уже загруженных на страницу стилей
     *
     * @type {Array}
     */
    private loadedStyles;
    /**
     * Список уже загруженных изображений
     *
     * @type {Array}
     */
    private loadedImages;
    /**
     * Загрузка сразу нескольких стилей
     *
     * @param styles
     * @returns {Promise<any>}
     */
    loadStyles(styles: {
        href: string;
        optionalAttributes?: any;
    }[]): Promise<any>;
    /**
     * Загрузка сразу нескольких скриптов
     *
     * @param scripts
     * @returns {Promise<any[]>}
     */
    loadScripts(scripts: {
        src: string;
        optionalAttributes?: any;
    }[]): Promise<any>;
    /**
     * Загрузка сразу нескольких изображений
     *
     * @param images
     * @returns {Promise<any[]>}
     */
    loadImages(images: {
        src: string;
        optionalAttributes?: any;
    }[]): Promise<any>;
    /**
     * Загрузка внешнего CSS-файла. Вернет promise в случае успеха загрузки файла, будет вызван resolve(), иначе reject()
     *
     * @param href
     * @param optionalAttributes
     * @returns {Promise<any>}
     */
    loadStyle(href: string, optionalAttributes?: any): Promise<any>;
    /**
     * Загрузка внешнего JS-файла. Вернет promise в случае успеха загрузки файла, будет вызван resolve(), иначе reject()
     *
     * @param src
     * @param optionalAttributes
     * @returns {Promise<any>}
     */
    loadScript(src: string, optionalAttributes?: any): Promise<any>;
    /**
     * Загрузка изображения. Вернет promise в случае успеха загрузки файла, будет вызван resolve(), иначе reject()
     *
     * @param src
     * @param optionalAttributes
     * @returns {Promise<any>}
     */
    loadImage(src: string, optionalAttributes?: any): Promise<any>;
}
