import { AbstractRefsService } from './abstract-refs.service';
import { GeoModel } from '../models/geo.model';
import { ResponseListModel } from '../models/response-list.model';
/**
 * Сервис для работы с географическими данными
 */
export declare class GeoService extends AbstractRefsService {
    refName: string;
    /**
     * Возвращает все страны
     * @returns {Promise<GeoModel[]>}
     */
    getAllCountries(): Promise<GeoModel[]>;
    /**
     * Возвращает все города в указанной стране
     * @param countryGuid Идентификатор страны
     * @returns {Promise<GeoModel[]>}
     */
    getAllCities(countryGuid: string): Promise<GeoModel[]>;
    /**
     * Возвращает все районы в указанном городе
     * @param cityGuid Идентификатор города
     * @returns {Promise<GeoModel[]>}
     */
    getAllDistricts(cityGuid: string): Promise<GeoModel[]>;
    /**
     * Возвращает страны по указанным параметрам
     * @param params Параметры для загрузки
     * @returns {Promise<ResponseListModel<GeoModel>>}
     */
    getCountries(params: any): Promise<ResponseListModel<GeoModel>>;
    /**
     * Возвращает города страны по указанным параметрам
     * @param countryGuid Идентификатор страны
     * @param params Параметры для загрузки
     * @returns {Promise<ResponseListModel<GeoModel>>}
     */
    getCities(countryGuid: string, params: any): Promise<ResponseListModel<GeoModel>>;
    /**
     * Возвращает районы города по указанным параметрам
     * @param cityGuid Идентификатор города
     * @param params Параметры для загрузки
     * @returns {Promise<ResponseListModel<any>>}
     */
    getDistricts(cityGuid: string, params: any): Promise<ResponseListModel<GeoModel>>;
    /**
     * Возвращает информацию о городе по его идентификатору
     * @param guid Идентификатор города
     * @returns {Promise<GeoModel>}
     */
    getCity(guid: string): Promise<GeoModel>;
    /**
     * Возвращает все записи из дерева на шаг выше
     * @param guid
     * @param params
     * @returns {Promise<any>}
     */
    getTreeUp(guid: string, params?: any): Promise<any>;
    /**
     * Возвращает все записи из дерева на шаг ниже
     * @param guid
     * @param params
     * @returns {Promise<any>}
     */
    getTreeDown(guid: string, params?: any): Promise<any>;
    /**
     * Возвращает информацию о стране по ее идентификатору
     * @param {string} guid Идентификатор страны
     * @returns {Promise<GeoModel>}
     */
    getCountry(guid: string): Promise<GeoModel>;
    /**
     * Загружает весь справочник
     * @param params
     * @param sort
     * @returns {Promise<T>}
     */
    getListAll(params: any, sort?: string): Promise<any>;
    /**
     * Возвращает список только отображаемых объектов
     * @param {any} params Параметры запроса
     * @returns {Promise<ResponseListModel<any>>}
     */
    getList(params: any): Promise<ResponseListModel<any>>;
    /**
     * Возвращает часть дерева от заданного узла до корня
     * @param {string} guid Идентификатор узла
     * @param {any} params Параметры запроса
     * @returns {Promise<any>}
     */
    treeUp(guid: string, params?: any): Promise<any>;
    /**
     * Возвращает поддерево, начиная от заданного узла
     * @param {string} guid Идентификатор узла
     * @param {any} params Параметры запроса
     * @returns {Promise<any>}
     */
    treeDown(guid: string, params?: any): Promise<any>;
}
