import { RealtorModel } from '../models/realtor.model';
import { HttpService } from './http.service';
import { ResponseListModel } from '../models/response-list.model';
import { RealtorInterface } from '../intefraces/realtor.interface';
import { RealtorsFilterInterface } from '../intefraces/realtors-filter.interface';
/**
 * Сервис риэлтеров
 */
export declare class RealtorsService {
    private httpService;
    static ESB_REALTORS_CHANNEL_NAME: string;
    static ESB_REALTORS_SHOW_INFO: string;
    /**
     * Base URL (точка входа) в микросервис пользователей (риэлтеров)
     */
    private usersEndPoint;
    constructor(httpService: HttpService);
    /**
     * Поиск риэлтеров
     *
     * @param query строка поиска
     * @param params дополнительные параметры для запроса
     */
    search(query: string, params: any): Promise<ResponseListModel<RealtorModel>>;
    /**
     * Получить список всех риелторов пользователя
     *
     * @param userGuid
     * @returns {Promise<T>}
     */
    getPartners(userGuid: string): Promise<ResponseListModel<RealtorInterface>>;
    /**
     * Добавить избранных риелторов пользователю
     *
     * @param userGuid
     * @param realtorsGuids
     * @returns {Promise<T>}
     */
    addPartners(userGuid: string, realtorsGuids: string[]): Promise<boolean>;
    /**
     * Установить избранных риелторов пользователю
     *
     * @param userGuid
     * @param realtors
     * @returns {Promise<T>}
     */
    setPartners(userGuid: string, realtors: string[]): Promise<boolean>;
    /**
     * Удалить избранных риелторов
     *
     * @param userGuid
     * @param realtorGuid
     * @returns {Promise<T>}
     */
    deletePartner(userGuid: string, realtorGuid: string): Promise<boolean>;
    /**
     * Фильтр по риелторам
     *
     * @returns {Promise<T>}
     * @param body
     * @param query
     */
    filter(body: RealtorsFilterInterface, query?: any): Promise<ResponseListModel<RealtorModel>>;
    /**
     * Фильтр по риелторам
     * @returns {Promise<ResponseListModel<RealtorModel>>}
     * @param body
     * @param query
     */
    filterMembers(body: RealtorsFilterInterface, query?: any): Promise<ResponseListModel<RealtorModel>>;
    /**
     * Получает информацию о риелторе по его идентификатору
     * @param {string} guid Идентификатор риелтора
     * @returns {Promise<T>}
     */
    load(guid: string): Promise<RealtorModel>;
    /**
     * Получение моделей пользователей по массиву идентификаторов
     * @param {string[]} guids Массив идентификаторов
     * @returns {Promise<any>}
     */
    getUsersByGuids(guids: string[]): Promise<any>;
    /**
     * Установка URL до сервиса users
     *
     * @param usersEndPoint
     */
    setUsersEndPoint(usersEndPoint: string): void;
}
